@@ -16,21 +16,21 @@ import sys
 from datetime import datetime
 from typing import Any, Dict, List, Type, Union, overload
 
-from botocore.client import ClientMeta
+from botocore.client import BaseClient, ClientMeta
 
 from .paginator import ListDeviceEventsPaginator, ListDevicesPaginator
 from .type_defs import (
-    ClaimDevicesByClaimCodeResponseResponseTypeDef,
-    DescribeDeviceResponseResponseTypeDef,
+    ClaimDevicesByClaimCodeResponseTypeDef,
+    DescribeDeviceResponseTypeDef,
     DeviceMethodTypeDef,
-    FinalizeDeviceClaimResponseResponseTypeDef,
-    GetDeviceMethodsResponseResponseTypeDef,
-    InitiateDeviceClaimResponseResponseTypeDef,
-    InvokeDeviceMethodResponseResponseTypeDef,
-    ListDeviceEventsResponseResponseTypeDef,
-    ListDevicesResponseResponseTypeDef,
-    ListTagsForResourceResponseResponseTypeDef,
-    UnclaimDeviceResponseResponseTypeDef,
+    FinalizeDeviceClaimResponseTypeDef,
+    GetDeviceMethodsResponseTypeDef,
+    InitiateDeviceClaimResponseTypeDef,
+    InvokeDeviceMethodResponseTypeDef,
+    ListDeviceEventsResponseTypeDef,
+    ListDevicesResponseTypeDef,
+    ListTagsForResourceResponseTypeDef,
+    UnclaimDeviceResponseTypeDef,
 )
 
 if sys.version_info >= (3, 8):
@@ -61,50 +61,55 @@ class Exceptions:
     ResourceNotFoundException: Type[BotocoreClientError]
 
 
-class IoT1ClickDevicesServiceClient:
+class IoT1ClickDevicesServiceClient(BaseClient):
     """
-    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/iot1click-devices.html#IoT1ClickDevicesService.Client)
+    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.103/reference/services/iot1click-devices.html#IoT1ClickDevicesService.Client)
     [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_iot1click_devices/client.html)
     """
 
     meta: ClientMeta
-    exceptions: Exceptions
+
+    @property
+    def exceptions(self) -> Exceptions:
+        """
+        IoT1ClickDevicesServiceClient exceptions.
+        """
 
     def can_paginate(self, operation_name: str) -> bool:
         """
         Check if an operation can be paginated.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/iot1click-devices.html#IoT1ClickDevicesService.Client.can_paginate)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.103/reference/services/iot1click-devices.html#IoT1ClickDevicesService.Client.can_paginate)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_iot1click_devices/client.html#can_paginate)
         """
 
     def claim_devices_by_claim_code(
         self, *, ClaimCode: str
-    ) -> ClaimDevicesByClaimCodeResponseResponseTypeDef:
+    ) -> ClaimDevicesByClaimCodeResponseTypeDef:
         """
         Adds device(s) to your account (i.e., claim one or more devices) if and only if
         you received a claim code with the device(s).
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/iot1click-devices.html#IoT1ClickDevicesService.Client.claim_devices_by_claim_code)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.103/reference/services/iot1click-devices.html#IoT1ClickDevicesService.Client.claim_devices_by_claim_code)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_iot1click_devices/client.html#claim_devices_by_claim_code)
         """
 
-    def describe_device(self, *, DeviceId: str) -> DescribeDeviceResponseResponseTypeDef:
+    def describe_device(self, *, DeviceId: str) -> DescribeDeviceResponseTypeDef:
         """
         Given a device ID, returns a DescribeDeviceResponse object describing the
         details of the device.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/iot1click-devices.html#IoT1ClickDevicesService.Client.describe_device)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.103/reference/services/iot1click-devices.html#IoT1ClickDevicesService.Client.describe_device)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_iot1click_devices/client.html#describe_device)
         """
 
     def finalize_device_claim(
         self, *, DeviceId: str, Tags: Dict[str, str] = None
-    ) -> FinalizeDeviceClaimResponseResponseTypeDef:
+    ) -> FinalizeDeviceClaimResponseTypeDef:
         """
         Given a device ID, finalizes the claim request for the associated device.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/iot1click-devices.html#IoT1ClickDevicesService.Client.finalize_device_claim)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.103/reference/services/iot1click-devices.html#IoT1ClickDevicesService.Client.finalize_device_claim)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_iot1click_devices/client.html#finalize_device_claim)
         """
 
@@ -118,23 +123,23 @@ class IoT1ClickDevicesServiceClient:
         """
         Generate a presigned url given a client, its method, and arguments.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/iot1click-devices.html#IoT1ClickDevicesService.Client.generate_presigned_url)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.103/reference/services/iot1click-devices.html#IoT1ClickDevicesService.Client.generate_presigned_url)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_iot1click_devices/client.html#generate_presigned_url)
         """
 
-    def get_device_methods(self, *, DeviceId: str) -> GetDeviceMethodsResponseResponseTypeDef:
+    def get_device_methods(self, *, DeviceId: str) -> GetDeviceMethodsResponseTypeDef:
         """
         Given a device ID, returns the invokable methods associated with the device.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/iot1click-devices.html#IoT1ClickDevicesService.Client.get_device_methods)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.103/reference/services/iot1click-devices.html#IoT1ClickDevicesService.Client.get_device_methods)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_iot1click_devices/client.html#get_device_methods)
         """
 
-    def initiate_device_claim(self, *, DeviceId: str) -> InitiateDeviceClaimResponseResponseTypeDef:
+    def initiate_device_claim(self, *, DeviceId: str) -> InitiateDeviceClaimResponseTypeDef:
         """
         Given a device ID, initiates a claim request for the associated device.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/iot1click-devices.html#IoT1ClickDevicesService.Client.initiate_device_claim)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.103/reference/services/iot1click-devices.html#IoT1ClickDevicesService.Client.initiate_device_claim)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_iot1click_devices/client.html#initiate_device_claim)
         """
 
@@ -144,12 +149,12 @@ class IoT1ClickDevicesServiceClient:
         DeviceId: str,
         DeviceMethod: "DeviceMethodTypeDef" = None,
         DeviceMethodParameters: str = None
-    ) -> InvokeDeviceMethodResponseResponseTypeDef:
+    ) -> InvokeDeviceMethodResponseTypeDef:
         """
         Given a device ID, issues a request to invoke a named device method (with
         possible parameters).
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/iot1click-devices.html#IoT1ClickDevicesService.Client.invoke_device_method)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.103/reference/services/iot1click-devices.html#IoT1ClickDevicesService.Client.invoke_device_method)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_iot1click_devices/client.html#invoke_device_method)
         """
 
@@ -161,32 +166,30 @@ class IoT1ClickDevicesServiceClient:
         ToTimeStamp: Union[datetime, str],
         MaxResults: int = None,
         NextToken: str = None
-    ) -> ListDeviceEventsResponseResponseTypeDef:
+    ) -> ListDeviceEventsResponseTypeDef:
         """
         Using a device ID, returns a DeviceEventsResponse object containing an array of
         events for the device.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/iot1click-devices.html#IoT1ClickDevicesService.Client.list_device_events)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.103/reference/services/iot1click-devices.html#IoT1ClickDevicesService.Client.list_device_events)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_iot1click_devices/client.html#list_device_events)
         """
 
     def list_devices(
         self, *, DeviceType: str = None, MaxResults: int = None, NextToken: str = None
-    ) -> ListDevicesResponseResponseTypeDef:
+    ) -> ListDevicesResponseTypeDef:
         """
         Lists the 1-Click compatible devices associated with your AWS account.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/iot1click-devices.html#IoT1ClickDevicesService.Client.list_devices)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.103/reference/services/iot1click-devices.html#IoT1ClickDevicesService.Client.list_devices)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_iot1click_devices/client.html#list_devices)
         """
 
-    def list_tags_for_resource(
-        self, *, ResourceArn: str
-    ) -> ListTagsForResourceResponseResponseTypeDef:
+    def list_tags_for_resource(self, *, ResourceArn: str) -> ListTagsForResourceResponseTypeDef:
         """
         Lists the tags associated with the specified resource ARN.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/iot1click-devices.html#IoT1ClickDevicesService.Client.list_tags_for_resource)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.103/reference/services/iot1click-devices.html#IoT1ClickDevicesService.Client.list_tags_for_resource)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_iot1click_devices/client.html#list_tags_for_resource)
         """
 
@@ -194,15 +197,15 @@ class IoT1ClickDevicesServiceClient:
         """
         Adds or updates the tags associated with the resource ARN.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/iot1click-devices.html#IoT1ClickDevicesService.Client.tag_resource)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.103/reference/services/iot1click-devices.html#IoT1ClickDevicesService.Client.tag_resource)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_iot1click_devices/client.html#tag_resource)
         """
 
-    def unclaim_device(self, *, DeviceId: str) -> UnclaimDeviceResponseResponseTypeDef:
+    def unclaim_device(self, *, DeviceId: str) -> UnclaimDeviceResponseTypeDef:
         """
         Disassociates a device from your AWS account using its device ID.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/iot1click-devices.html#IoT1ClickDevicesService.Client.unclaim_device)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.103/reference/services/iot1click-devices.html#IoT1ClickDevicesService.Client.unclaim_device)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_iot1click_devices/client.html#unclaim_device)
         """
 
@@ -211,7 +214,7 @@ class IoT1ClickDevicesServiceClient:
         Using tag keys, deletes the tags (key/value pairs) associated with the specified
         resource ARN.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/iot1click-devices.html#IoT1ClickDevicesService.Client.untag_resource)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.103/reference/services/iot1click-devices.html#IoT1ClickDevicesService.Client.untag_resource)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_iot1click_devices/client.html#untag_resource)
         """
 
@@ -220,7 +223,7 @@ class IoT1ClickDevicesServiceClient:
         Using a Boolean value (true or false), this operation enables or disables the
         device given a device ID.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/iot1click-devices.html#IoT1ClickDevicesService.Client.update_device_state)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.103/reference/services/iot1click-devices.html#IoT1ClickDevicesService.Client.update_device_state)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_iot1click_devices/client.html#update_device_state)
         """
 
@@ -229,13 +232,13 @@ class IoT1ClickDevicesServiceClient:
         self, operation_name: Literal["list_device_events"]
     ) -> ListDeviceEventsPaginator:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/iot1click-devices.html#IoT1ClickDevicesService.Paginator.ListDeviceEvents)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.103/reference/services/iot1click-devices.html#IoT1ClickDevicesService.Paginator.ListDeviceEvents)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_iot1click_devices/paginators.html#listdeviceeventspaginator)
         """
 
     @overload
     def get_paginator(self, operation_name: Literal["list_devices"]) -> ListDevicesPaginator:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/iot1click-devices.html#IoT1ClickDevicesService.Paginator.ListDevices)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.103/reference/services/iot1click-devices.html#IoT1ClickDevicesService.Paginator.ListDevices)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_iot1click_devices/paginators.html#listdevicespaginator)
         """
