@@ -26,8 +26,8 @@ from typing import Iterator, Union
 from botocore.paginate import Paginator as Boto3Paginator
 
 from .type_defs import (
-    ListDeviceEventsResponseResponseTypeDef,
-    ListDevicesResponseResponseTypeDef,
+    ListDeviceEventsResponseTypeDef,
+    ListDevicesResponseTypeDef,
     PaginatorConfigTypeDef,
 )
 
@@ -36,7 +36,7 @@ __all__ = ("ListDeviceEventsPaginator", "ListDevicesPaginator")
 
 class ListDeviceEventsPaginator(Boto3Paginator):
     """
-    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/iot1click-devices.html#IoT1ClickDevicesService.Paginator.ListDeviceEvents)
+    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.103/reference/services/iot1click-devices.html#IoT1ClickDevicesService.Paginator.ListDeviceEvents)
     [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_iot1click_devices/paginators.html#listdeviceeventspaginator)
     """
 
@@ -47,23 +47,23 @@ class ListDeviceEventsPaginator(Boto3Paginator):
         FromTimeStamp: Union[datetime, str],
         ToTimeStamp: Union[datetime, str],
         PaginationConfig: PaginatorConfigTypeDef = None
-    ) -> Iterator[ListDeviceEventsResponseResponseTypeDef]:
+    ) -> Iterator[ListDeviceEventsResponseTypeDef]:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/iot1click-devices.html#IoT1ClickDevicesService.Paginator.ListDeviceEvents.paginate)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.103/reference/services/iot1click-devices.html#IoT1ClickDevicesService.Paginator.ListDeviceEvents.paginate)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_iot1click_devices/paginators.html#listdeviceeventspaginator)
         """
 
 
 class ListDevicesPaginator(Boto3Paginator):
     """
-    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/iot1click-devices.html#IoT1ClickDevicesService.Paginator.ListDevices)
+    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.103/reference/services/iot1click-devices.html#IoT1ClickDevicesService.Paginator.ListDevices)
     [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_iot1click_devices/paginators.html#listdevicespaginator)
     """
 
     def paginate(
         self, *, DeviceType: str = None, PaginationConfig: PaginatorConfigTypeDef = None
-    ) -> Iterator[ListDevicesResponseResponseTypeDef]:
+    ) -> Iterator[ListDevicesResponseTypeDef]:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/iot1click-devices.html#IoT1ClickDevicesService.Paginator.ListDevices.paginate)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.103/reference/services/iot1click-devices.html#IoT1ClickDevicesService.Paginator.ListDevices.paginate)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_iot1click_devices/paginators.html#listdevicespaginator)
         """
